﻿using System.Windows.Input;
using Microsoft.Windows.Controls.Ribbon;

namespace RibbonCommands
{
  ///<summary>
  /// Base class for custom <see cref="RibbonCommand"/>
  /// implementations. Implements internal event listeners for
  /// <see cref="RibbonCommand.Executed"/> and
  /// <see cref="RibbonCommand.CanExecute"/> events.
  ///</summary>
  public abstract class RibbonCommandBase : RibbonCommand
  {
    /// <summary>
    /// Creates the command and registers weak event listeners.
    /// </summary>
    protected RibbonCommandBase()
    {
      Executed += OnExecute;
      CanExecute += OnCanExecute;
    }


    /// <summary>
    /// Determines whether the command can be executed or not.
    /// The default implementation always allows that.
    /// </summary>
    protected virtual void OnCanExecute(object sender, CanExecuteRoutedEventArgs e)
    {
      e.CanExecute = true;
    }


    /// <summary>
    /// Command implementation - executes command logic.
    /// </summary>
    protected abstract void OnExecute(object sender, ExecutedRoutedEventArgs e);
  }
}